@@ -14,6 +14,7 @@
    along with Pyxgram.  If not, see <http://www.gnu.org/licenses/>. """
 
 import time
+import random
 import os
 from functools import partial
 import telegram
@@ -60,6 +61,7 @@ class Basebot:
         """Init method of BaseBot class"""
         self.updater=telegram.ext.Updater(token=token)
         self.logging=logging
+        self._jobqueue=None
         self._help=''
         self.dispatcher=self.updater.dispatcher
         if self.logging:
@@ -146,3 +148,27 @@ class Basebot:
         if chat_id is None:
             chat_id=update.message.chat_id
         context.bot.send_message(chat_id,text)
+    def setup_jqe(self):
+        """Setup's the Jobqueue"""
+        if self._jobqueue is None:
+            self._jobqueue=self.updater.job_queue
+        else:
+            self.log.error('Jobqueue was already initiated')
+    def jqe_run_repeating(self,function,date):
+        """Its a shorcut for the Jobqueue of telegram module
+        function - This argument need to be a function
+        date - The time in seconds or datetime.datetime"""
+        if self._jobqueue is None:
+            self.log.error('Jobqueue not initiated')
+        else:
+            self._jobqueue.run_repeating(function,date)
+    def jqe_kill(self):
+        if self._jobqueue is None:
+            self.log.error('Jobqueue not initiated')
+        else:
+            self._jobqueue.stop()
+    def jqe_start(self):
+        if self._jobqueue is None:
+            self.log.error('Jobqueue not initiated')
+        else:
+            self._jobqueue.start()
